TL;DR — Starting the week of Monday, Sept 28 2026, we are removing CUDA 13.0 from the PyTorch nightly build matrix and CI. Nightly CUDA builds will be 13.2 (stable / default) and 13.4 (prototype). No GPU architecture support is lost. PyTorch 2.14 and earlier are unaffected. If you pin cu130, move to cu132.
This is tracked in pytorch/pytorch#190385.
Why we are removing it
CUDA Toolkit 13.2.2 fixes a compiler bug that has been present since CUDA 12.8. Compiler-inserted thread reconvergence could fail and leave stale or corrupted values in registers, producing silently incorrect results — no crash, no error, just wrong numbers.
The bug only triggers in kernels with two or more nested levels of thread divergence, where the compiler elided convergence instructions for one or more of those levels. Kernels with a single level of divergence are unaffected. From the illustrative example in the NVIDIA notes:
__global__ void affected(const int* in, int* out) {
int tid = threadIdx.x;
if (tid < 16) { // Level 1 divergence
if (in[tid] > 0) { // Level 2 divergence, nested
// A register written here can carry a stale value
// across the reconvergence point.
out[tid] = compute(in[tid]);
}
// Implicit reconvergence: failure can manifest here.
}
}
Details: CUDA Toolkit 13.2.2 release notes.
CUDA 13.0 predates the fix. Since 13.2 already provides identical architecture coverage, continuing to build and ship a toolkit with a known silent-miscompilation class buys us nothing and exposes users to it. Thanks to @DEKHTIARJonathan for raising this on the RFC.
What you need to do
If you install the default nightly — nothing. You will start receiving a CUDA 13.2 build instead of 13.0.
If you pin cu130, update the index URL:
-pip install --pre torch --index-url https://download.pytorch.org/whl/nightly/cu130
+pip install --pre torch --index-url https://download.pytorch.org/whl/nightly/cu132
If you maintain CI that references cu130 nightly artifacts — Docker tags, index URLs, build-matrix entries — please update to cu132 during the week of Sept 28. Builds stop being produced after the change lands; pinned references will go stale rather than fail loudly.
Feedback
If this breaks a workflow you depend on, please comment on pytorch/pytorch#190385